@@ -44,7 +44,7 @@ use IO::Select;
 use IPC::Open3;
 use Symbol qw(gensym);
 
-our $VERSION = '2.0.3';
+our $VERSION = '2.0.4';
 
 =head1 DESCRIPTION
 
@@ -83,7 +83,7 @@ without any additional options.
 C<OPTIONS> - are passed in a hash like fashion, using key and value pairs.
 Combining the command with additional C<OPTIONS> also requires the hash key C<command> to be set.
 
-See L<Method C<setArrProcess()>|setArrProcess ( CONFIGURATIONS )>
+See L<Method C<setArrProcess()>|/"setArrProcess ( CONFIGURATIONS )">
 
 =back
 
@@ -145,7 +145,7 @@ B<Parameters:>
 
 C<CONFIGURATIONS> are passed in a hash like fashion, using key and value pairs.
 
-See L<Method C<setArrProcess()>|setArrProcess ( CONFIGURATIONS )>
+See L<Method C<setArrProcess()>|/"setArrProcess ( CONFIGURATIONS )">
 
 =back
 
@@ -243,11 +243,13 @@ If the process is expected to run longer it is useful to set it to avoid excessi
 It is also important for multiple process execusions, because other processes will not
 be checked before the read has not timed out.
 
-See L<Method C<setName()>|setName ( NAME )>
+See L<Method C<setName()>|/"setName ( NAME )">
 
-See L<Method C<setCommand()>|setCommand ( COMMAND )>
+See L<Method C<setCommand()>|/"setCommand ( COMMAND )">
 
-See L<Method C<setReadTimeout()>|setReadTimeout ( TIMEOUT )>
+See L<Method C<setTimeout()>|/"setTimeout ( TIMEOUT )">
+
+See L<Method C<setReadTimeout()>|/"setReadTimeout ( TIMEOUT )">
 
 =back
 
@@ -285,7 +287,7 @@ sub setArrProcess {
 
 Shorthand for C<setArrProcess()>
 
-See L<Method C<setArrProcess()>>
+See L<Method C<setArrProcess()>|/"setArrProcess ( CONFIGURATIONS )">
 
 =back
 
@@ -305,6 +307,8 @@ sub set {
 
 This Method will asign a Name to the process.
 
+The C<NAME> of the C<Process::SubProcess> object will reflect in the logs.
+
 This is useful when there are several processes with the same command running and
 a more prettier readable name is desired.
 
@@ -341,7 +345,7 @@ B<Parameters:>
 
 C<COMMAND> - is a single scalar parameter that will be interpreted as command to executed
 
-See L<Method C<Launch()>>
+See L<Method C<Launch()>|/"Launch ()">
 
 =back
 
@@ -376,7 +380,7 @@ It is also important for multiple process execusions, because other processes wi
 be checked before the read has not timed out.
 It can only be set when the Sub Process is not running.
 
-See L<Method C<Launch()>|Launch ()>
+See L<Method C<Launch()>|/"Launch ()">
 
 =back
 
@@ -422,7 +426,7 @@ be terminated.
 The C<EXECUTIONTIMEOUT> property must be a positive numeric value. Setting it to a
 negative value C< -1 > will disable the Execution Timeout
 
-See L<Method C<Launch()>>
+See L<Method C<Launch()>|/"Launch ()">
 
 =back
 
@@ -509,7 +513,7 @@ monitor its execution and read its outputs
 B<Returns:> It returns C< 1 > when the process was launched correctly.
 otherwise it returns C< 0 >.
 
-See L<Method C<Check()>|Check ()>
+See L<Method C<Check()>|/"Check ()">
 
 =back
 
@@ -676,7 +680,7 @@ read its output.
 B<Returns:> It returns C< 1 > when the process is still running
 otherwise it returns C< 0 >.
 
-See L<Method C<Launch()>|Launch ()>
+See L<Method C<Launch()>|/"Launch ()">
 
 =back
 
@@ -868,6 +872,28 @@ sub Check {
     return $irng;
 }
 
+=pod
+
+=over 4
+
+=item Read ()
+
+This method reads the C<STDOUT> and C<STDERR> outputs from a running process
+which was started with the C<Launch()> method.
+
+When the process is not started yet it does not do anything.
+
+If a C<TIMEOUT> is set through the C<setReadTimeout()> method the B<Manager Process> keeps
+waiting for output until the C<TIMEOUT> is fulfilled.
+
+See L<Method C<setReadTimeout()>|/"setReadTimeout ( TIMEOUT )">
+
+See L<Method C<Launch()>|/"Launch ()">
+
+=back
+
+=cut
+
 sub Read {
     my $self = $_[0];
 
@@ -1007,6 +1033,33 @@ sub Read {
          #	&& $self->{"_pid"} > 0)
 }
 
+=pod
+
+=over 4
+
+=item Read ()
+
+This method calls the C<Check()> method continuously for a started process
+which was started with the C<Launch()> method until the C<Check()> method tells that
+the process is finished.
+
+If a C<TIMEOUT> is set through the C<setTimeout()> method the B<Manager Process> will
+terminate the process after the C<TIMEOUT> is fulfilled.
+When a process times out an B<Error Code> of C< 4 > will be set.
+
+B<Returns:> It returns C< 1 > when the process has finished correctly.
+It returns C< 0 > when the process hat to be terminated.
+
+See L<Method C<Check()>|/"Check ()">
+
+See L<Method C<Launch()>|/"Launch ()">
+
+See L<Method C<setTimeout()>|/"setTimeout ( TIMEOUT )">
+
+=back
+
+=cut
+
 sub Wait {
     my $self = $_[0];
 
@@ -1201,16 +1254,48 @@ sub clearErrors() {
 #----------------------------------------------------------------------------
 #Consultation Methods
 
-sub getProcessID {
-    my $self = shift;
+=pod
 
-    return $self->{"_pid"};
+=over 4
+
+=item getProcessID
+
+This Method will return the B<ProcessID> of the process which was assigned by the system
+at launch time.
+
+If the process was not launched yet it will return C< -1 >.
+
+B<Returns:> The B<ProcessID> of the process assigned by the system.
+
+See L<Method C<Launch()>|/"Launch ()">
+
+=back
+
+=cut
+
+sub getProcessID {
+    return $_->{"_pid"};
 }
 
-sub getName {
-    my $self = shift;
+=pod
 
-    return $self->{"_name"};
+=over 4
+
+=item getName
+
+This Method will return the Name to the C<Process::SubProcess> object if any was assigned
+with the C<setName()> method.
+
+B<Returns:> The C<NAME> of the C<Process::SubProcess> object as string.
+
+See L<Method C<setName()>|/"setName ( NAME )">
+
+=back
+
+=cut
+
+sub getName {
+    return $_->{"_name"};
 }
 
 sub getNameComplete {
